"use strict";
// Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license.
// See LICENSE in the project root for license information.
Object.defineProperty(exports, "__esModule", { value: true });
exports.minifySingleFile = void 0;
const terser_1 = require("terser");
require("./Base54");
/**
 * Minifies a single chunk of code. Factored out for reuse between ThreadPoolMinifier and SynchronousMinifier
 * Mutates terserOptions.output.comments to support comment extraction
 * @internal
 */
function minifySingleFile(request, terserOptions) {
    const output = terserOptions.output || {};
    const { mangle: originalMangle } = terserOptions;
    const mangle = originalMangle === false ? false : typeof originalMangle === 'object' ? { ...originalMangle } : {};
    const finalOptions = {
        ...terserOptions,
        output,
        mangle
    };
    output.comments = false;
    const { code, nameForMap, hash, externals } = request;
    if (mangle && externals) {
        mangle.reserved = mangle.reserved ? externals.concat(mangle.reserved) : externals;
    }
    finalOptions.sourceMap = nameForMap
        ? {
            asObject: true
        }
        : false;
    const minified = terser_1.minify({
        [nameForMap || 'code']: code
    }, finalOptions);
    if (minified.error) {
        return {
            error: minified.error,
            code: undefined,
            map: undefined,
            hash
        };
    }
    return {
        error: undefined,
        code: minified.code,
        map: minified.map,
        hash
    };
}
exports.minifySingleFile = minifySingleFile;
//# sourceMappingURL=MinifySingleFile.js.map